@@ -3,14 +3,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4200';
+our $VERSION = '0.4201';
 
+use Moo;
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
 use List::Util qw(sum0);
 use Math::Bezier ();
 use MIDI::Util qw(dura_size reverse_dump set_time_signature);
-use Moo;
 use Music::CreatingRhythms ();
 use Music::Duration ();
 use Music::RhythmSet::Util qw(upsize);
@@ -636,7 +636,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4200
+version 0.4201
 
 =head1 SYNOPSIS
 
@@ -687,12 +687,12 @@ version 0.4200
 
   print 'Count: ', $d->counter, "\n";
 
-  $d->write;
-
   # As a convenience, and sometimes necessity:
   $d->set_bpm(200); # handy for tempo changes
   $d->set_channel;  # reset back to 9 if ever changed
 
+  $d->write;
+
 =head1 DESCRIPTION
 
 This module provides handy defaults and tools to produce a MIDI score
@@ -1113,11 +1113,12 @@ different.
 
 =head2 set_volume
 
+  $d->set_volume;
   $d->set_volume($volume);
 
 Set the volume to the given argument (0-127).
 
-If not given a B<volume> arument, this method mutes (sets to C<0>).
+If not given a B<volume> argument, this method mutes (sets to C<0>).
 
 =head2 sync
 
